from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import result_pb2 as _result_pb2
import common_models_pb2 as _common_models_pb2_1
import toi_pb2 as _toi_pb2
import analysis_pb2 as _analysis_pb2
import common_models_pb2 as _common_models_pb2_1_1
import algorithm_config_pb2 as _algorithm_config_pb2
import common_models_pb2 as _common_models_pb2_1_1_1
import algorithm_pb2 as _algorithm_pb2
import algorithm_version_pb2 as _algorithm_version_pb2
import visualization_pb2 as _visualization_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from result_pb2 import ExportFile as ExportFile
from result_pb2 import ExportCredentials as ExportCredentials
from result_pb2 import Result as Result
from result_pb2 import ResultGetRequest as ResultGetRequest
from result_pb2 import ResultGetResponse as ResultGetResponse
from result_pb2 import ResultFilterCreateRequest as ResultFilterCreateRequest
from result_pb2 import ResultFilterCreateResponse as ResultFilterCreateResponse
from result_pb2 import ResultFilterMappingCreateRequest as ResultFilterMappingCreateRequest
from result_pb2 import ResultFilterMappingCreateResponse as ResultFilterMappingCreateResponse
from result_pb2 import ResultFilterListRequest as ResultFilterListRequest
from result_pb2 import ResultFilter as ResultFilter
from result_pb2 import ResultFilterListResponse as ResultFilterListResponse
from analysis_pb2 import AnalysisAlgorithmNode as AnalysisAlgorithmNode
from analysis_pb2 import AnalysisCreateRequest as AnalysisCreateRequest
from analysis_pb2 import AnalysisCreateResponse as AnalysisCreateResponse
from analysis_pb2 import AnalysisAlgorithmConfigNode as AnalysisAlgorithmConfigNode
from analysis_pb2 import AnalysisGetRequest as AnalysisGetRequest
from analysis_pb2 import Analysis as Analysis
from analysis_pb2 import AnalysisGetResponse as AnalysisGetResponse
from analysis_pb2 import AnalysisListRequest as AnalysisListRequest
from analysis_pb2 import AnalysisListResponse as AnalysisListResponse
from algorithm_config_pb2 import AlgorithmConfig as AlgorithmConfig
from algorithm_config_pb2 import AlgorithmConfigCreateRequest as AlgorithmConfigCreateRequest
from algorithm_config_pb2 import AlgorithmConfigCreateResponse as AlgorithmConfigCreateResponse
from algorithm_config_pb2 import AlgorithmConfigUpdateRequest as AlgorithmConfigUpdateRequest
from algorithm_config_pb2 import AlgorithmConfigUpdateResponse as AlgorithmConfigUpdateResponse
from algorithm_config_pb2 import AlgorithmConfigGetRequest as AlgorithmConfigGetRequest
from algorithm_config_pb2 import AlgorithmConfigGetResponse as AlgorithmConfigGetResponse
from algorithm_config_pb2 import AlgorithmConfigListRequest as AlgorithmConfigListRequest
from algorithm_config_pb2 import AlgorithmConfigListResponse as AlgorithmConfigListResponse
from algorithm_config_pb2 import AlgorithmConfigDeleteRequest as AlgorithmConfigDeleteRequest
from algorithm_config_pb2 import AlgorithmConfigDeleteResponse as AlgorithmConfigDeleteResponse
from algorithm_config_pb2 import AlgorithmConfigDeprecateRequest as AlgorithmConfigDeprecateRequest
from algorithm_config_pb2 import AlgorithmConfigDeprecateResponse as AlgorithmConfigDeprecateResponse
from algorithm_config_pb2 import AlgorithmConfigDeactivateRequest as AlgorithmConfigDeactivateRequest
from algorithm_config_pb2 import AlgorithmConfigDeactivateResponse as AlgorithmConfigDeactivateResponse
from visualization_pb2 import Visualization as Visualization
from visualization_pb2 import VisualizationGetRequest as VisualizationGetRequest
from visualization_pb2 import VisualizationGetResponse as VisualizationGetResponse
from visualization_pb2 import Visualizer as Visualizer
from visualization_pb2 import VisualizerConfig as VisualizerConfig
from visualization_pb2 import VisualizerConfigAlgoVersionCreateRequest as VisualizerConfigAlgoVersionCreateRequest
from visualization_pb2 import VisualizerConfigAlgoVersionCreateResponse as VisualizerConfigAlgoVersionCreateResponse
from visualization_pb2 import VisualizerConfigAlgoGetRequest as VisualizerConfigAlgoGetRequest
from visualization_pb2 import VisualizerConfigAlgo as VisualizerConfigAlgo
from visualization_pb2 import VisualizerConfigAlgoGetResponse as VisualizerConfigAlgoGetResponse
from visualization_pb2 import VisualizerConfigAlgoConfigCreateRequest as VisualizerConfigAlgoConfigCreateRequest
from visualization_pb2 import VisualizerConfigAlgoConfigCreateResponse as VisualizerConfigAlgoConfigCreateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectResultFilter(_message.Message):
    __slots__ = ("filter", "analysis_config_id", "node_name", "project_id")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    filter: _result_pb2.ResultFilter
    analysis_config_id: str
    node_name: str
    project_id: str
    def __init__(self, filter: _Optional[_Union[_result_pb2.ResultFilter, _Mapping]] = ..., analysis_config_id: _Optional[str] = ..., node_name: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ProjectResultStatus(_message.Message):
    __slots__ = ("analysis_config_id", "aoi_id", "result_indicator")
    class ProjectResultIndicator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_RESULT_STATUS: _ClassVar[ProjectResultStatus.ProjectResultIndicator]
        NOT_STARTED: _ClassVar[ProjectResultStatus.ProjectResultIndicator]
        IN_PROGRESS: _ClassVar[ProjectResultStatus.ProjectResultIndicator]
        AVAILABLE: _ClassVar[ProjectResultStatus.ProjectResultIndicator]
        FAILED: _ClassVar[ProjectResultStatus.ProjectResultIndicator]
    UNKNOWN_RESULT_STATUS: ProjectResultStatus.ProjectResultIndicator
    NOT_STARTED: ProjectResultStatus.ProjectResultIndicator
    IN_PROGRESS: ProjectResultStatus.ProjectResultIndicator
    AVAILABLE: ProjectResultStatus.ProjectResultIndicator
    FAILED: ProjectResultStatus.ProjectResultIndicator
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_INDICATOR_FIELD_NUMBER: _ClassVar[int]
    analysis_config_id: str
    aoi_id: str
    result_indicator: ProjectResultStatus.ProjectResultIndicator
    def __init__(self, analysis_config_id: _Optional[str] = ..., aoi_id: _Optional[str] = ..., result_indicator: _Optional[_Union[ProjectResultStatus.ProjectResultIndicator, str]] = ...) -> None: ...

class ProjectResultDownloadInput(_message.Message):
    __slots__ = ("project_id", "observation_start_ts", "observation_end_ts", "file_type", "data_type")
    class ProjectResultDownloadFileType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_FILE_TYPE: _ClassVar[ProjectResultDownloadInput.ProjectResultDownloadFileType]
        CSV: _ClassVar[ProjectResultDownloadInput.ProjectResultDownloadFileType]
        SHAPEFILE: _ClassVar[ProjectResultDownloadInput.ProjectResultDownloadFileType]
        GEOJSON: _ClassVar[ProjectResultDownloadInput.ProjectResultDownloadFileType]
        PARQUET: _ClassVar[ProjectResultDownloadInput.ProjectResultDownloadFileType]
    UNKNOWN_FILE_TYPE: ProjectResultDownloadInput.ProjectResultDownloadFileType
    CSV: ProjectResultDownloadInput.ProjectResultDownloadFileType
    SHAPEFILE: ProjectResultDownloadInput.ProjectResultDownloadFileType
    GEOJSON: ProjectResultDownloadInput.ProjectResultDownloadFileType
    PARQUET: ProjectResultDownloadInput.ProjectResultDownloadFileType
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    OBSERVATION_START_TS_FIELD_NUMBER: _ClassVar[int]
    OBSERVATION_END_TS_FIELD_NUMBER: _ClassVar[int]
    FILE_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    observation_start_ts: _timestamp_pb2.Timestamp
    observation_end_ts: _timestamp_pb2.Timestamp
    file_type: ProjectResultDownloadInput.ProjectResultDownloadFileType
    data_type: str
    def __init__(self, project_id: _Optional[str] = ..., observation_start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., observation_end_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., file_type: _Optional[_Union[ProjectResultDownloadInput.ProjectResultDownloadFileType, str]] = ..., data_type: _Optional[str] = ...) -> None: ...

class ProjectResultDownloadOutput(_message.Message):
    __slots__ = ("download_url", "download_status", "created_ts", "file_size_bytes", "download_input")
    class ProjectResultDownloadStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_DOWNLOAD_STATUS: _ClassVar[ProjectResultDownloadOutput.ProjectResultDownloadStatus]
        PROCESSING: _ClassVar[ProjectResultDownloadOutput.ProjectResultDownloadStatus]
        SUCCEEDED: _ClassVar[ProjectResultDownloadOutput.ProjectResultDownloadStatus]
        FAILED: _ClassVar[ProjectResultDownloadOutput.ProjectResultDownloadStatus]
    UNKNOWN_DOWNLOAD_STATUS: ProjectResultDownloadOutput.ProjectResultDownloadStatus
    PROCESSING: ProjectResultDownloadOutput.ProjectResultDownloadStatus
    SUCCEEDED: ProjectResultDownloadOutput.ProjectResultDownloadStatus
    FAILED: ProjectResultDownloadOutput.ProjectResultDownloadStatus
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_TS_FIELD_NUMBER: _ClassVar[int]
    FILE_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_INPUT_FIELD_NUMBER: _ClassVar[int]
    download_url: str
    download_status: ProjectResultDownloadOutput.ProjectResultDownloadStatus
    created_ts: _timestamp_pb2.Timestamp
    file_size_bytes: int
    download_input: ProjectResultDownloadInput
    def __init__(self, download_url: _Optional[str] = ..., download_status: _Optional[_Union[ProjectResultDownloadOutput.ProjectResultDownloadStatus, str]] = ..., created_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., file_size_bytes: _Optional[int] = ..., download_input: _Optional[_Union[ProjectResultDownloadInput, _Mapping]] = ...) -> None: ...

class ProjectResult(_message.Message):
    __slots__ = ("result_get_response", "analysis_algorithm_node", "algorithm_config")
    RESULT_GET_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_ALGORITHM_NODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_FIELD_NUMBER: _ClassVar[int]
    result_get_response: _result_pb2.ResultGetResponse
    analysis_algorithm_node: _analysis_pb2.AnalysisAlgorithmNode
    algorithm_config: _algorithm_config_pb2.AlgorithmConfig
    def __init__(self, result_get_response: _Optional[_Union[_result_pb2.ResultGetResponse, _Mapping]] = ..., analysis_algorithm_node: _Optional[_Union[_analysis_pb2.AnalysisAlgorithmNode, _Mapping]] = ..., algorithm_config: _Optional[_Union[_algorithm_config_pb2.AlgorithmConfig, _Mapping]] = ...) -> None: ...

class ProjectResultFilterMappingCreateRequest(_message.Message):
    __slots__ = ("project_result_filters",)
    PROJECT_RESULT_FILTERS_FIELD_NUMBER: _ClassVar[int]
    project_result_filters: _containers.RepeatedCompositeFieldContainer[ProjectResultFilter]
    def __init__(self, project_result_filters: _Optional[_Iterable[_Union[ProjectResultFilter, _Mapping]]] = ...) -> None: ...

class ProjectResultFilterMappingCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectResultFilterMappingDeleteRequest(_message.Message):
    __slots__ = ("project_result_filters",)
    PROJECT_RESULT_FILTERS_FIELD_NUMBER: _ClassVar[int]
    project_result_filters: _containers.RepeatedCompositeFieldContainer[ProjectResultFilter]
    def __init__(self, project_result_filters: _Optional[_Iterable[_Union[ProjectResultFilter, _Mapping]]] = ...) -> None: ...

class ProjectResultFilterMappingDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectResultGetRequest(_message.Message):
    __slots__ = ("project_id", "analysis_config_id", "source_aoi_version", "visualizer_type", "include_export_files")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_TYPE_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_EXPORT_FILES_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    analysis_config_id: str
    source_aoi_version: int
    visualizer_type: _visualization_pb2.Visualizer.VisualizerType
    include_export_files: bool
    def __init__(self, project_id: _Optional[str] = ..., analysis_config_id: _Optional[str] = ..., source_aoi_version: _Optional[int] = ..., visualizer_type: _Optional[_Union[_visualization_pb2.Visualizer.VisualizerType, str]] = ..., include_export_files: bool = ...) -> None: ...

class ProjectResultGetResponse(_message.Message):
    __slots__ = ("status_code", "project_results")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_RESULTS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project_results: _containers.RepeatedCompositeFieldContainer[ProjectResult]
    def __init__(self, status_code: _Optional[int] = ..., project_results: _Optional[_Iterable[_Union[ProjectResult, _Mapping]]] = ...) -> None: ...

class ProjectResultGetStatusRequest(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class ProjectResultGetStatusResponse(_message.Message):
    __slots__ = ("status_code", "results_status", "progress")
    class Progress(_message.Message):
        __slots__ = ("running", "succeeded", "failed")
        RUNNING_FIELD_NUMBER: _ClassVar[int]
        SUCCEEDED_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        running: float
        succeeded: float
        failed: float
        def __init__(self, running: _Optional[float] = ..., succeeded: _Optional[float] = ..., failed: _Optional[float] = ...) -> None: ...
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESULTS_STATUS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    results_status: _containers.RepeatedCompositeFieldContainer[ProjectResultStatus]
    progress: ProjectResultGetStatusResponse.Progress
    def __init__(self, status_code: _Optional[int] = ..., results_status: _Optional[_Iterable[_Union[ProjectResultStatus, _Mapping]]] = ..., progress: _Optional[_Union[ProjectResultGetStatusResponse.Progress, _Mapping]] = ...) -> None: ...

class ProjectResultGetDownloadRequest(_message.Message):
    __slots__ = ("download_input",)
    DOWNLOAD_INPUT_FIELD_NUMBER: _ClassVar[int]
    download_input: ProjectResultDownloadInput
    def __init__(self, download_input: _Optional[_Union[ProjectResultDownloadInput, _Mapping]] = ...) -> None: ...

class ProjectResultGetDownloadResponse(_message.Message):
    __slots__ = ("status_code", "download_outputs")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    download_outputs: _containers.RepeatedCompositeFieldContainer[ProjectResultDownloadOutput]
    def __init__(self, status_code: _Optional[int] = ..., download_outputs: _Optional[_Iterable[_Union[ProjectResultDownloadOutput, _Mapping]]] = ...) -> None: ...

class ProjectResultGenerateDownloadRequest(_message.Message):
    __slots__ = ("download_input",)
    DOWNLOAD_INPUT_FIELD_NUMBER: _ClassVar[int]
    download_input: ProjectResultDownloadInput
    def __init__(self, download_input: _Optional[_Union[ProjectResultDownloadInput, _Mapping]] = ...) -> None: ...

class ProjectResultGenerateDownloadResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ("id", "topic_id", "channel_id", "filter")
    class Filter(_message.Message):
        __slots__ = ("data_types", "algorithm_version_ids")
        DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
        ALGORITHM_VERSION_IDS_FIELD_NUMBER: _ClassVar[int]
        data_types: _containers.RepeatedScalarFieldContainer[str]
        algorithm_version_ids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, data_types: _Optional[_Iterable[str]] = ..., algorithm_version_ids: _Optional[_Iterable[str]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    id: str
    topic_id: str
    channel_id: str
    filter: Subscription.Filter
    def __init__(self, id: _Optional[str] = ..., topic_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., filter: _Optional[_Union[Subscription.Filter, _Mapping]] = ...) -> None: ...

class SubscriptionCreateRequest(_message.Message):
    __slots__ = ("subscriptions",)
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    subscriptions: _containers.RepeatedCompositeFieldContainer[Subscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[Subscription, _Mapping]]] = ...) -> None: ...

class SubscriptionCreateResponse(_message.Message):
    __slots__ = ("status_code", "subscription_ids")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_IDS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    subscription_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, status_code: _Optional[int] = ..., subscription_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class Topic(_message.Message):
    __slots__ = ("id", "description")
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    description: str
    def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class TopicListRequest(_message.Message):
    __slots__ = ("search_text",)
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    def __init__(self, search_text: _Optional[str] = ...) -> None: ...

class TopicListResponse(_message.Message):
    __slots__ = ("status_code", "topics")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    topics: _containers.RepeatedCompositeFieldContainer[Topic]
    def __init__(self, status_code: _Optional[int] = ..., topics: _Optional[_Iterable[_Union[Topic, _Mapping]]] = ...) -> None: ...

class Channel(_message.Message):
    __slots__ = ("id", "type")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class ChannelListRequest(_message.Message):
    __slots__ = ("search_text",)
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    def __init__(self, search_text: _Optional[str] = ...) -> None: ...

class ChannelListResponse(_message.Message):
    __slots__ = ("status_code", "channels")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    channels: _containers.RepeatedCompositeFieldContainer[Channel]
    def __init__(self, status_code: _Optional[int] = ..., channels: _Optional[_Iterable[_Union[Channel, _Mapping]]] = ...) -> None: ...

class SubscriptionDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class SubscriptionDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class SubscriptionListRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class SubscriptionListResponse(_message.Message):
    __slots__ = ("status_code", "subscriptions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    subscriptions: _containers.RepeatedCompositeFieldContainer[Subscription]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., subscriptions: _Optional[_Iterable[_Union[Subscription, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class NotificationSendRequest(_message.Message):
    __slots__ = ("topic", "message", "user_id", "filters")
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    topic: str
    message: str
    user_id: str
    filters: _struct_pb2.Struct
    def __init__(self, topic: _Optional[str] = ..., message: _Optional[str] = ..., user_id: _Optional[str] = ..., filters: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class NotificationSendResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class Notification(_message.Message):
    __slots__ = ("id", "subscription_id", "message_data", "delivered_on", "status")
    ID_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_DATA_FIELD_NUMBER: _ClassVar[int]
    DELIVERED_ON_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    subscription_id: str
    message_data: _struct_pb2.Struct
    delivered_on: _timestamp_pb2.Timestamp
    status: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., subscription_id: _Optional[str] = ..., message_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., delivered_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., status: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class NotificationListRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class NotificationListResponse(_message.Message):
    __slots__ = ("status_code", "notifications", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    notifications: _containers.RepeatedCompositeFieldContainer[Notification]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., notifications: _Optional[_Iterable[_Union[Notification, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class NotificationUpdateRequest(_message.Message):
    __slots__ = ("id", "status")
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class NotificationUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import toi_pb2 as _toi_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from toi_pb2 import Cadence as Cadence
from toi_pb2 import Recurrence as Recurrence
from toi_pb2 import TOI as TOI
from toi_pb2 import TOICreateRequest as TOICreateRequest
from toi_pb2 import TOICreateResponse as TOICreateResponse
from toi_pb2 import TOIDeleteRequest as TOIDeleteRequest
from toi_pb2 import TOIDeleteResponse as TOIDeleteResponse
from toi_pb2 import TOIGetRequest as TOIGetRequest
from toi_pb2 import TOIGetResponse as TOIGetResponse
from toi_pb2 import TOIListRequest as TOIListRequest
from toi_pb2 import TOIListResponse as TOIListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ExportFile(_message.Message):
    __slots__ = ("url", "file_size_bytes")
    URL_FIELD_NUMBER: _ClassVar[int]
    FILE_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    url: str
    file_size_bytes: int
    def __init__(self, url: _Optional[str] = ..., file_size_bytes: _Optional[int] = ...) -> None: ...

class ExportCredentials(_message.Message):
    __slots__ = ("credentials", "base_url_template")
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    BASE_URL_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    credentials: _struct_pb2.Struct
    base_url_template: str
    def __init__(self, credentials: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., base_url_template: _Optional[str] = ...) -> None: ...

class Result(_message.Message):
    __slots__ = ("id", "created_on", "source_aoi_version", "dest_aoi_version", "algo_config_class", "algo_config_subclass", "observations", "data_type", "algorithm_computation_id")
    class Observation(_message.Message):
        __slots__ = ("id", "data_view_id", "created_on", "start_ts", "end_ts", "value", "status", "measurements", "export_file")
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_STATUS: _ClassVar[Result.Observation.Status]
            COMPLETE: _ClassVar[Result.Observation.Status]
            PARTIAL: _ClassVar[Result.Observation.Status]
        UNKNOWN_STATUS: Result.Observation.Status
        COMPLETE: Result.Observation.Status
        PARTIAL: Result.Observation.Status
        class Measurement(_message.Message):
            __slots__ = ("id", "dimensions")
            ID_FIELD_NUMBER: _ClassVar[int]
            DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
            id: str
            dimensions: _struct_pb2.Struct
            def __init__(self, id: _Optional[str] = ..., dimensions: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        DATA_VIEW_ID_FIELD_NUMBER: _ClassVar[int]
        CREATED_ON_FIELD_NUMBER: _ClassVar[int]
        START_TS_FIELD_NUMBER: _ClassVar[int]
        END_TS_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        MEASUREMENTS_FIELD_NUMBER: _ClassVar[int]
        EXPORT_FILE_FIELD_NUMBER: _ClassVar[int]
        id: str
        data_view_id: str
        created_on: _timestamp_pb2.Timestamp
        start_ts: _timestamp_pb2.Timestamp
        end_ts: _timestamp_pb2.Timestamp
        value: _struct_pb2.Struct
        status: Result.Observation.Status
        measurements: _containers.RepeatedCompositeFieldContainer[Result.Observation.Measurement]
        export_file: ExportFile
        def __init__(self, id: _Optional[str] = ..., data_view_id: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., status: _Optional[_Union[Result.Observation.Status, str]] = ..., measurements: _Optional[_Iterable[_Union[Result.Observation.Measurement, _Mapping]]] = ..., export_file: _Optional[_Union[ExportFile, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    SOURCE_AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    DEST_AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    ALGO_CONFIG_CLASS_FIELD_NUMBER: _ClassVar[int]
    ALGO_CONFIG_SUBCLASS_FIELD_NUMBER: _ClassVar[int]
    OBSERVATIONS_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_on: _timestamp_pb2.Timestamp
    source_aoi_version: int
    dest_aoi_version: int
    algo_config_class: str
    algo_config_subclass: str
    observations: _containers.RepeatedCompositeFieldContainer[Result.Observation]
    data_type: str
    algorithm_computation_id: str
    def __init__(self, id: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., source_aoi_version: _Optional[int] = ..., dest_aoi_version: _Optional[int] = ..., algo_config_class: _Optional[str] = ..., algo_config_subclass: _Optional[str] = ..., observations: _Optional[_Iterable[_Union[Result.Observation, _Mapping]]] = ..., data_type: _Optional[str] = ..., algorithm_computation_id: _Optional[str] = ...) -> None: ...

class ResultGetRequest(_message.Message):
    __slots__ = ("source_aoi_version", "dest_aoi_version", "algo_config_class", "algo_config_subclass", "created_on", "observation_start_ts", "max_observation_start_ts", "observation_status", "data_type", "pagination", "algorithm_computation_ids", "analysis_computation_ids", "include_export_files")
    SOURCE_AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    DEST_AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    ALGO_CONFIG_CLASS_FIELD_NUMBER: _ClassVar[int]
    ALGO_CONFIG_SUBCLASS_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    OBSERVATION_START_TS_FIELD_NUMBER: _ClassVar[int]
    MAX_OBSERVATION_START_TS_FIELD_NUMBER: _ClassVar[int]
    OBSERVATION_STATUS_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_IDS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATION_IDS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_EXPORT_FILES_FIELD_NUMBER: _ClassVar[int]
    source_aoi_version: int
    dest_aoi_version: int
    algo_config_class: str
    algo_config_subclass: str
    created_on: _timestamp_pb2.Timestamp
    observation_start_ts: _timestamp_pb2.Timestamp
    max_observation_start_ts: _timestamp_pb2.Timestamp
    observation_status: Result.Observation.Status
    data_type: str
    pagination: _common_models_pb2_1.Pagination
    algorithm_computation_ids: _containers.RepeatedScalarFieldContainer[str]
    analysis_computation_ids: _containers.RepeatedScalarFieldContainer[str]
    include_export_files: bool
    def __init__(self, source_aoi_version: _Optional[int] = ..., dest_aoi_version: _Optional[int] = ..., algo_config_class: _Optional[str] = ..., algo_config_subclass: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., observation_start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_observation_start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., observation_status: _Optional[_Union[Result.Observation.Status, str]] = ..., data_type: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., algorithm_computation_ids: _Optional[_Iterable[str]] = ..., analysis_computation_ids: _Optional[_Iterable[str]] = ..., include_export_files: bool = ...) -> None: ...

class ResultGetResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "results", "export_credentials")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    EXPORT_CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2_1.Pagination
    results: _containers.RepeatedCompositeFieldContainer[Result]
    export_credentials: ExportCredentials
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., results: _Optional[_Iterable[_Union[Result, _Mapping]]] = ..., export_credentials: _Optional[_Union[ExportCredentials, _Mapping]] = ...) -> None: ...

class ResultFilterCreateRequest(_message.Message):
    __slots__ = ("data_type", "expression", "expression_context", "description")
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    data_type: str
    expression: str
    expression_context: _struct_pb2.Struct
    description: str
    def __init__(self, data_type: _Optional[str] = ..., expression: _Optional[str] = ..., expression_context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., description: _Optional[str] = ...) -> None: ...

class ResultFilterCreateResponse(_message.Message):
    __slots__ = ("status_code", "result_filter_id")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESULT_FILTER_ID_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    result_filter_id: str
    def __init__(self, status_code: _Optional[int] = ..., result_filter_id: _Optional[str] = ...) -> None: ...

class ResultFilterMappingCreateRequest(_message.Message):
    __slots__ = ("computation_id", "result_filter_id")
    COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FILTER_ID_FIELD_NUMBER: _ClassVar[int]
    computation_id: str
    result_filter_id: str
    def __init__(self, computation_id: _Optional[str] = ..., result_filter_id: _Optional[str] = ...) -> None: ...

class ResultFilterMappingCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ResultFilterListRequest(_message.Message):
    __slots__ = ("pagination", "data_types")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2_1.Pagination
    data_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., data_types: _Optional[_Iterable[str]] = ...) -> None: ...

class ResultFilter(_message.Message):
    __slots__ = ("id", "name", "description", "expression", "expression_context", "data_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    expression: str
    expression_context: _struct_pb2.Struct
    data_type: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., expression: _Optional[str] = ..., expression_context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., data_type: _Optional[str] = ...) -> None: ...

class ResultFilterListResponse(_message.Message):
    __slots__ = ("status_code", "result_filters", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESULT_FILTERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    result_filters: _containers.RepeatedCompositeFieldContainer[ResultFilter]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., result_filters: _Optional[_Iterable[_Union[ResultFilter, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import analysis_pb2 as _analysis_pb2
import common_models_pb2 as _common_models_pb2_1
import algorithm_version_pb2 as _algorithm_version_pb2
import common_models_pb2 as _common_models_pb2_1_1
import algorithm_pb2 as _algorithm_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from analysis_pb2 import AnalysisAlgorithmNode as AnalysisAlgorithmNode
from analysis_pb2 import AnalysisCreateRequest as AnalysisCreateRequest
from analysis_pb2 import AnalysisCreateResponse as AnalysisCreateResponse
from analysis_pb2 import AnalysisAlgorithmConfigNode as AnalysisAlgorithmConfigNode
from analysis_pb2 import AnalysisGetRequest as AnalysisGetRequest
from analysis_pb2 import Analysis as Analysis
from analysis_pb2 import AnalysisGetResponse as AnalysisGetResponse
from analysis_pb2 import AnalysisListRequest as AnalysisListRequest
from analysis_pb2 import AnalysisListResponse as AnalysisListResponse
from algorithm_version_pb2 import Manifest as Manifest
from algorithm_version_pb2 import AlgorithmVersion as AlgorithmVersion
from algorithm_version_pb2 import AlgorithmVersionCreateRequest as AlgorithmVersionCreateRequest
from algorithm_version_pb2 import AlgorithmVersionCreateResponse as AlgorithmVersionCreateResponse
from algorithm_version_pb2 import AlgorithmVersionGetRequest as AlgorithmVersionGetRequest
from algorithm_version_pb2 import AlgorithmVersionGetResponse as AlgorithmVersionGetResponse
from algorithm_version_pb2 import AlgorithmVersionListRequest as AlgorithmVersionListRequest
from algorithm_version_pb2 import AlgorithmVersionListResponse as AlgorithmVersionListResponse
from algorithm_version_pb2 import AlgorithmVersionDeprecateRequest as AlgorithmVersionDeprecateRequest
from algorithm_version_pb2 import AlgorithmVersionDeprecateResponse as AlgorithmVersionDeprecateResponse
from algorithm_version_pb2 import AlgorithmVersionDeactivateRequest as AlgorithmVersionDeactivateRequest
from algorithm_version_pb2 import AlgorithmVersionDeactivateResponse as AlgorithmVersionDeactivateResponse
from algorithm_version_pb2 import AlgorithmVersionActivateRequest as AlgorithmVersionActivateRequest
from algorithm_version_pb2 import AlgorithmVersionActivateResponse as AlgorithmVersionActivateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisManifest(_message.Message):
    __slots__ = ("manifest_version", "metadata", "algorithm_nodes")
    class Metadata(_message.Message):
        __slots__ = ("description", "version", "tags")
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        TAGS_FIELD_NUMBER: _ClassVar[int]
        description: str
        version: str
        tags: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, description: _Optional[str] = ..., version: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...
    MANIFEST_VERSION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_NODES_FIELD_NUMBER: _ClassVar[int]
    manifest_version: str
    metadata: AnalysisManifest.Metadata
    algorithm_nodes: _containers.RepeatedCompositeFieldContainer[_analysis_pb2.AnalysisAlgorithmNode]
    def __init__(self, manifest_version: _Optional[str] = ..., metadata: _Optional[_Union[AnalysisManifest.Metadata, _Mapping]] = ..., algorithm_nodes: _Optional[_Iterable[_Union[_analysis_pb2.AnalysisAlgorithmNode, _Mapping]]] = ...) -> None: ...

class AnalysisVersion(_message.Message):
    __slots__ = ("id", "analysis", "analysis_manifest", "created_on", "algorithm_versions")
    ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_MANIFEST_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    analysis: _analysis_pb2.Analysis
    analysis_manifest: AnalysisManifest
    created_on: _timestamp_pb2.Timestamp
    algorithm_versions: _containers.RepeatedCompositeFieldContainer[_algorithm_version_pb2.AlgorithmVersion]
    def __init__(self, id: _Optional[str] = ..., analysis: _Optional[_Union[_analysis_pb2.Analysis, _Mapping]] = ..., analysis_manifest: _Optional[_Union[AnalysisManifest, _Mapping]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., algorithm_versions: _Optional[_Iterable[_Union[_algorithm_version_pb2.AlgorithmVersion, _Mapping]]] = ...) -> None: ...

class AnalysisVersionCreateRequest(_message.Message):
    __slots__ = ("analysis_id", "analysis_manifest")
    ANALYSIS_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_MANIFEST_FIELD_NUMBER: _ClassVar[int]
    analysis_id: str
    analysis_manifest: AnalysisManifest
    def __init__(self, analysis_id: _Optional[str] = ..., analysis_manifest: _Optional[_Union[AnalysisManifest, _Mapping]] = ...) -> None: ...

class AnalysisVersionCreateResponse(_message.Message):
    __slots__ = ("status_code", "analysis_version")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_VERSION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_version: AnalysisVersion
    def __init__(self, status_code: _Optional[int] = ..., analysis_version: _Optional[_Union[AnalysisVersion, _Mapping]] = ...) -> None: ...

class AnalysisVersionGetRequest(_message.Message):
    __slots__ = ("ids", "include_manifest", "include_algorithm_details", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_MANIFEST_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_ALGORITHM_DETAILS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    include_manifest: bool
    include_algorithm_details: bool
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., include_manifest: bool = ..., include_algorithm_details: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisVersionGetResponse(_message.Message):
    __slots__ = ("status_code", "analysis_versions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_versions: _containers.RepeatedCompositeFieldContainer[AnalysisVersion]
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_versions: _Optional[_Iterable[_Union[AnalysisVersion, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisVersionListRequest(_message.Message):
    __slots__ = ("analysis_id", "tag", "search_text", "min_created_on", "max_created_on", "include_manifest", "include_all_versions", "pagination")
    ANALYSIS_ID_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_MANIFEST_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_ALL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    analysis_id: str
    tag: str
    search_text: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    include_manifest: bool
    include_all_versions: bool
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, analysis_id: _Optional[str] = ..., tag: _Optional[str] = ..., search_text: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., include_manifest: bool = ..., include_all_versions: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisVersionListResponse(_message.Message):
    __slots__ = ("status_code", "analysis_versions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_versions: _containers.RepeatedCompositeFieldContainer[AnalysisVersion]
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_versions: _Optional[_Iterable[_Union[AnalysisVersion, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AOITransaction(_message.Message):
    __slots__ = ("id", "status", "created_on", "updated_on")
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ON_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: str
    created_on: _timestamp_pb2.Timestamp
    updated_on: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., status: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AOIIdentifier(_message.Message):
    __slots__ = ("aoi_id", "aoi_version_id")
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    aoi_id: str
    aoi_version_id: int
    def __init__(self, aoi_id: _Optional[str] = ..., aoi_version_id: _Optional[int] = ...) -> None: ...

class AOIObject(_message.Message):
    __slots__ = ("aoi_identifier", "geom_wkt", "lat", "long", "name", "area_km2", "category", "type", "source", "country", "state", "tags", "attributes", "timezone")
    AOI_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    GEOM_WKT_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LONG_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    AREA_KM2_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    aoi_identifier: AOIIdentifier
    geom_wkt: str
    lat: float
    long: float
    name: str
    area_km2: float
    category: str
    type: str
    source: str
    country: str
    state: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    attributes: _struct_pb2.Struct
    timezone: str
    def __init__(self, aoi_identifier: _Optional[_Union[AOIIdentifier, _Mapping]] = ..., geom_wkt: _Optional[str] = ..., lat: _Optional[float] = ..., long: _Optional[float] = ..., name: _Optional[str] = ..., area_km2: _Optional[float] = ..., category: _Optional[str] = ..., type: _Optional[str] = ..., source: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., attributes: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., timezone: _Optional[str] = ...) -> None: ...

class AOIVersion(_message.Message):
    __slots__ = ("id", "aoi_id", "creation_timestamp", "creator", "aoi_name", "geom_wkt", "lat", "long", "area_km2", "category", "type", "source", "country", "state", "tags", "attributes", "timezone")
    ID_FIELD_NUMBER: _ClassVar[int]
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    CREATION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    AOI_NAME_FIELD_NUMBER: _ClassVar[int]
    GEOM_WKT_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LONG_FIELD_NUMBER: _ClassVar[int]
    AREA_KM2_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    id: int
    aoi_id: str
    creation_timestamp: _timestamp_pb2.Timestamp
    creator: str
    aoi_name: str
    geom_wkt: str
    lat: float
    long: float
    area_km2: float
    category: str
    type: str
    source: str
    country: str
    state: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    attributes: _struct_pb2.Struct
    timezone: str
    def __init__(self, id: _Optional[int] = ..., aoi_id: _Optional[str] = ..., creation_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., creator: _Optional[str] = ..., aoi_name: _Optional[str] = ..., geom_wkt: _Optional[str] = ..., lat: _Optional[float] = ..., long: _Optional[float] = ..., area_km2: _Optional[float] = ..., category: _Optional[str] = ..., type: _Optional[str] = ..., source: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., attributes: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., timezone: _Optional[str] = ...) -> None: ...

class AOIInput(_message.Message):
    __slots__ = ("aoi_id", "geom_wkt", "name", "category", "type", "tags", "attributes")
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    GEOM_WKT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    aoi_id: str
    geom_wkt: str
    name: str
    category: str
    type: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    attributes: _struct_pb2.Struct
    def __init__(self, aoi_id: _Optional[str] = ..., geom_wkt: _Optional[str] = ..., name: _Optional[str] = ..., category: _Optional[str] = ..., type: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., attributes: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class AOICreateRequest(_message.Message):
    __slots__ = ("aoi_inputs", "aoi_collection_id")
    AOI_INPUTS_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    aoi_inputs: _containers.RepeatedCompositeFieldContainer[AOIInput]
    aoi_collection_id: str
    def __init__(self, aoi_inputs: _Optional[_Iterable[_Union[AOIInput, _Mapping]]] = ..., aoi_collection_id: _Optional[str] = ...) -> None: ...

class AOICreateResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_identifiers", "area_km2")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_IDENTIFIERS_FIELD_NUMBER: _ClassVar[int]
    AREA_KM2_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2.Pagination
    aoi_identifiers: _containers.RepeatedCompositeFieldContainer[AOIIdentifier]
    area_km2: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., aoi_identifiers: _Optional[_Iterable[_Union[AOIIdentifier, _Mapping]]] = ..., area_km2: _Optional[_Iterable[float]] = ...) -> None: ...

class AOIUploadRequest(_message.Message):
    __slots__ = ("aoi_collection_id", "chunk")
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    aoi_collection_id: str
    chunk: bytes
    def __init__(self, aoi_collection_id: _Optional[str] = ..., chunk: _Optional[bytes] = ...) -> None: ...

class AOIUploadResponse(_message.Message):
    __slots__ = ("status_code", "aoi_transaction")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_transaction: AOITransaction
    def __init__(self, status_code: _Optional[int] = ..., aoi_transaction: _Optional[_Union[AOITransaction, _Mapping]] = ...) -> None: ...

class AOIGetRequest(_message.Message):
    __slots__ = ("ids", "verbose", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    verbose: bool
    pagination: _common_models_pb2.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., verbose: bool = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AOIGetResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_versions")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2.Pagination
    aoi_versions: _containers.RepeatedCompositeFieldContainer[AOIVersion]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., aoi_versions: _Optional[_Iterable[_Union[AOIVersion, _Mapping]]] = ...) -> None: ...

class AOIUpdateRequest(_message.Message):
    __slots__ = ("aoi_id", "aoi_modification_input")
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_MODIFICATION_INPUT_FIELD_NUMBER: _ClassVar[int]
    aoi_id: str
    aoi_modification_input: AOIInput
    def __init__(self, aoi_id: _Optional[str] = ..., aoi_modification_input: _Optional[_Union[AOIInput, _Mapping]] = ...) -> None: ...

class AOIUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



import data_type_pb2 as _data_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from data_type_pb2 import DataType as DataType
from data_type_pb2 import DataTypeCreateRequest as DataTypeCreateRequest
from data_type_pb2 import DataTypeCreateResponse as DataTypeCreateResponse
from data_type_pb2 import DataTypeGetRequest as DataTypeGetRequest
from data_type_pb2 import DataTypeGetResponse as DataTypeGetResponse
from data_type_pb2 import DataTypeListRequest as DataTypeListRequest
from data_type_pb2 import DataTypeListResponse as DataTypeListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class DataSource(_message.Message):
    __slots__ = ("id", "name", "description", "data_types", "delivery_lag_seconds", "display_name", "indicator", "data_explorer")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_LAG_SECONDS_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    INDICATOR_FIELD_NUMBER: _ClassVar[int]
    DATA_EXPLORER_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    data_types: _containers.RepeatedCompositeFieldContainer[_data_type_pb2.DataType]
    delivery_lag_seconds: int
    display_name: str
    indicator: str
    data_explorer: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., data_types: _Optional[_Iterable[_Union[_data_type_pb2.DataType, _Mapping]]] = ..., delivery_lag_seconds: _Optional[int] = ..., display_name: _Optional[str] = ..., indicator: _Optional[str] = ..., data_explorer: bool = ...) -> None: ...

class DataSourceGetRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class DataSourceGetResponse(_message.Message):
    __slots__ = ("status_code", "data_sources")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    data_sources: _containers.RepeatedCompositeFieldContainer[DataSource]
    def __init__(self, status_code: _Optional[int] = ..., data_sources: _Optional[_Iterable[_Union[DataSource, _Mapping]]] = ...) -> None: ...

class DataSourceListRequest(_message.Message):
    __slots__ = ("search_text",)
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    def __init__(self, search_text: _Optional[str] = ...) -> None: ...

class DataSourceListResponse(_message.Message):
    __slots__ = ("status_code", "data_sources")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    data_sources: _containers.RepeatedCompositeFieldContainer[DataSource]
    def __init__(self, status_code: _Optional[int] = ..., data_sources: _Optional[_Iterable[_Union[DataSource, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import credit_pb2 as credit__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in credit_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class CreditApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.add = channel.unary_unary(
                '/oi.papi.credit.CreditApi/add',
                request_serializer=credit__pb2.CreditAddRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditAddResponse.FromString,
                _registered_method=True)
        self.remove = channel.unary_unary(
                '/oi.papi.credit.CreditApi/remove',
                request_serializer=credit__pb2.CreditRemoveRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditRemoveResponse.FromString,
                _registered_method=True)
        self.refund = channel.unary_unary(
                '/oi.papi.credit.CreditApi/refund',
                request_serializer=credit__pb2.CreditRefundRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditRefundResponse.FromString,
                _registered_method=True)
        self.set_algorithm = channel.unary_unary(
                '/oi.papi.credit.CreditApi/set_algorithm',
                request_serializer=credit__pb2.CreditAlgorithmMultiplierSetRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditAlgorithmMultiplierSetResponse.FromString,
                _registered_method=True)
        self.set_data_source = channel.unary_unary(
                '/oi.papi.credit.CreditApi/set_data_source',
                request_serializer=credit__pb2.CreditDataSourceMultiplierSetRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditDataSourceMultiplierSetResponse.FromString,
                _registered_method=True)
        self.estimate = channel.unary_unary(
                '/oi.papi.credit.CreditApi/estimate',
                request_serializer=credit__pb2.CreditEstimateRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditEstimateResponse.FromString,
                _registered_method=True)
        self.summary = channel.unary_unary(
                '/oi.papi.credit.CreditApi/summary',
                request_serializer=credit__pb2.CreditSummaryRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditSummaryResponse.FromString,
                _registered_method=True)
        self.transactions = channel.unary_unary(
                '/oi.papi.credit.CreditApi/transactions',
                request_serializer=credit__pb2.CreditTransactionsRequest.SerializeToString,
                response_deserializer=credit__pb2.CreditTransactionsResponse.FromString,
                _registered_method=True)


class CreditApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def add(self, request, context):
        """
        Add credits to the specified CreditSource (department). Currently, this can only be done at the department level by an Admin user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove(self, request, context):
        """
        Removes credits from a department. Currently, this can only be done at the department level.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def refund(self, request, context):
        """
        Refunds credits to a department. This can only be done by an admin user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_algorithm(self, request, context):
        """
        Assign a price to the specified Algorithm. Price must be a multiple of $0.001. This can only be done by an admin user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_data_source(self, request, context):
        """
        Assign a price to the specified DataSource. Price must be a multiple of $0.001. This can only be done by an admin user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def estimate(self, request, context):
        """
        Returns an estimate of the credits required to compute results for the specified Algorithm.
        Estimates the full cost, including open orders based on the ending date of the specified TOI.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def summary(self, request, context):
        """
        Retrieves the credit summary for the specified user's department.
        As credits are associated with a department, all users of the a department see the same credit summary.
        Currently, this can only be done at the department level.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def transactions(self, request, context):
        """
        Retrieves the detailed view of all Transactions associated with a department.
        Can filter for a time range or Transaction type. Currently, this can only be done at the department level.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CreditApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'add': grpc.unary_unary_rpc_method_handler(
                    servicer.add,
                    request_deserializer=credit__pb2.CreditAddRequest.FromString,
                    response_serializer=credit__pb2.CreditAddResponse.SerializeToString,
            ),
            'remove': grpc.unary_unary_rpc_method_handler(
                    servicer.remove,
                    request_deserializer=credit__pb2.CreditRemoveRequest.FromString,
                    response_serializer=credit__pb2.CreditRemoveResponse.SerializeToString,
            ),
            'refund': grpc.unary_unary_rpc_method_handler(
                    servicer.refund,
                    request_deserializer=credit__pb2.CreditRefundRequest.FromString,
                    response_serializer=credit__pb2.CreditRefundResponse.SerializeToString,
            ),
            'set_algorithm': grpc.unary_unary_rpc_method_handler(
                    servicer.set_algorithm,
                    request_deserializer=credit__pb2.CreditAlgorithmMultiplierSetRequest.FromString,
                    response_serializer=credit__pb2.CreditAlgorithmMultiplierSetResponse.SerializeToString,
            ),
            'set_data_source': grpc.unary_unary_rpc_method_handler(
                    servicer.set_data_source,
                    request_deserializer=credit__pb2.CreditDataSourceMultiplierSetRequest.FromString,
                    response_serializer=credit__pb2.CreditDataSourceMultiplierSetResponse.SerializeToString,
            ),
            'estimate': grpc.unary_unary_rpc_method_handler(
                    servicer.estimate,
                    request_deserializer=credit__pb2.CreditEstimateRequest.FromString,
                    response_serializer=credit__pb2.CreditEstimateResponse.SerializeToString,
            ),
            'summary': grpc.unary_unary_rpc_method_handler(
                    servicer.summary,
                    request_deserializer=credit__pb2.CreditSummaryRequest.FromString,
                    response_serializer=credit__pb2.CreditSummaryResponse.SerializeToString,
            ),
            'transactions': grpc.unary_unary_rpc_method_handler(
                    servicer.transactions,
                    request_deserializer=credit__pb2.CreditTransactionsRequest.FromString,
                    response_serializer=credit__pb2.CreditTransactionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.credit.CreditApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.credit.CreditApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CreditApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/add',
            credit__pb2.CreditAddRequest.SerializeToString,
            credit__pb2.CreditAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/remove',
            credit__pb2.CreditRemoveRequest.SerializeToString,
            credit__pb2.CreditRemoveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def refund(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/refund',
            credit__pb2.CreditRefundRequest.SerializeToString,
            credit__pb2.CreditRefundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def set_algorithm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/set_algorithm',
            credit__pb2.CreditAlgorithmMultiplierSetRequest.SerializeToString,
            credit__pb2.CreditAlgorithmMultiplierSetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def set_data_source(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/set_data_source',
            credit__pb2.CreditDataSourceMultiplierSetRequest.SerializeToString,
            credit__pb2.CreditDataSourceMultiplierSetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def estimate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/estimate',
            credit__pb2.CreditEstimateRequest.SerializeToString,
            credit__pb2.CreditEstimateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/summary',
            credit__pb2.CreditSummaryRequest.SerializeToString,
            credit__pb2.CreditSummaryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def transactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.credit.CreditApi/transactions',
            credit__pb2.CreditTransactionsRequest.SerializeToString,
            credit__pb2.CreditTransactionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_analysis_config.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'project_analysis_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__version__pb2 = analysis__config__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = analysis__config__pb2.analysis_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__config__pb2 = analysis__config__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = analysis__config__pb2.algorithm_config_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__computation__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__computation__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_config_pb2 import *
from terrascope_api.models.analysis_computation_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *
from terrascope_api.models.result_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dproject_analysis_config.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x15\x61nalysis_config.proto\x1a\x1a\x61nalysis_computation.proto\x1a\x14\x61oi_collection.proto\x1a\x0cresult.proto\"U\n\"ProjectAnalysisConfigUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61nalysis_config_ids\x18\x02 \x03(\t\":\n#ProjectAnalysisConfigUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x7f\n\x18ProjectAnalysisConfigApi\x12\x63\n\x06update\x12+.oi.papi.ProjectAnalysisConfigUpdateRequest\x1a,.oi.papi.ProjectAnalysisConfigUpdateResponseP\x00P\x01P\x02P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_analysis_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTANALYSISCONFIGUPDATEREQUEST']._serialized_start=150
  _globals['_PROJECTANALYSISCONFIGUPDATEREQUEST']._serialized_end=235
  _globals['_PROJECTANALYSISCONFIGUPDATERESPONSE']._serialized_start=237
  _globals['_PROJECTANALYSISCONFIGUPDATERESPONSE']._serialized_end=295
  _globals['_PROJECTANALYSISCONFIGAPI']._serialized_start=297
  _globals['_PROJECTANALYSISCONFIGAPI']._serialized_end=424
# @@protoc_insertion_point(module_scope)



import common_models_pb2 as _common_models_pb2
import subject_pb2 as _subject_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from subject_pb2 import Subject as Subject

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceRegisterTypeRequest(_message.Message):
    __slots__ = ("type",)
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: str
    def __init__(self, type: _Optional[str] = ...) -> None: ...

class ResourceRegisterTypeResponse(_message.Message):
    __slots__ = ("status_code", "value", "already_existed")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    ALREADY_EXISTED_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    value: int
    already_existed: bool
    def __init__(self, status_code: _Optional[int] = ..., value: _Optional[int] = ..., already_existed: bool = ...) -> None: ...

class ResourceTypesListRequest(_message.Message):
    __slots__ = ("value", "name", "regex")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REGEX_FIELD_NUMBER: _ClassVar[int]
    value: int
    name: str
    regex: bool
    def __init__(self, value: _Optional[int] = ..., name: _Optional[str] = ..., regex: bool = ...) -> None: ...

class ResourceTypesListResponse(_message.Message):
    __slots__ = ("type_to_name",)
    class TypeToNameEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: str
        def __init__(self, key: _Optional[int] = ..., value: _Optional[str] = ...) -> None: ...
    TYPE_TO_NAME_FIELD_NUMBER: _ClassVar[int]
    type_to_name: _containers.ScalarMap[int, str]
    def __init__(self, type_to_name: _Optional[_Mapping[int, str]] = ...) -> None: ...

class Resource(_message.Message):
    __slots__ = ("id", "type")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PERMISSION_RESOURCE_TYPE_UNKNOWN: _ClassVar[Resource.Type]
        ALGORITHM: _ClassVar[Resource.Type]
        ALGORITHM_COMPUTATION: _ClassVar[Resource.Type]
        ALGORITHM_CONFIG: _ClassVar[Resource.Type]
        ANALYSIS: _ClassVar[Resource.Type]
        ANALYSIS_COMPUTATION: _ClassVar[Resource.Type]
        ANALYSIS_CONFIG: _ClassVar[Resource.Type]
        AOI_COLLECTION: _ClassVar[Resource.Type]
        RESULT: _ClassVar[Resource.Type]
        TOI: _ClassVar[Resource.Type]
        DIRECT_RANGE_START: _ClassVar[Resource.Type]
        DATA_SOURCE: _ClassVar[Resource.Type]
        DATA_SOURCES: _ClassVar[Resource.Type]
        APPLICATION_RANGE_START: _ClassVar[Resource.Type]
        MOBILE_WORKFORCE_TASK: _ClassVar[Resource.Type]
        MOBILE_WORKFORCE_CAMPAIGN: _ClassVar[Resource.Type]
    PERMISSION_RESOURCE_TYPE_UNKNOWN: Resource.Type
    ALGORITHM: Resource.Type
    ALGORITHM_COMPUTATION: Resource.Type
    ALGORITHM_CONFIG: Resource.Type
    ANALYSIS: Resource.Type
    ANALYSIS_COMPUTATION: Resource.Type
    ANALYSIS_CONFIG: Resource.Type
    AOI_COLLECTION: Resource.Type
    RESULT: Resource.Type
    TOI: Resource.Type
    DIRECT_RANGE_START: Resource.Type
    DATA_SOURCE: Resource.Type
    DATA_SOURCES: Resource.Type
    APPLICATION_RANGE_START: Resource.Type
    MOBILE_WORKFORCE_TASK: Resource.Type
    MOBILE_WORKFORCE_CAMPAIGN: Resource.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: Resource.Type
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Resource.Type, str]] = ...) -> None: ...

class ResourceCreateRequest(_message.Message):
    __slots__ = ("resources", "parent")
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    PARENT_FIELD_NUMBER: _ClassVar[int]
    resources: _containers.RepeatedCompositeFieldContainer[Resource]
    parent: Resource
    def __init__(self, resources: _Optional[_Iterable[_Union[Resource, _Mapping]]] = ..., parent: _Optional[_Union[Resource, _Mapping]] = ...) -> None: ...

class ResourceCreateResponse(_message.Message):
    __slots__ = ("status_code", "resources", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    resources: _containers.RepeatedCompositeFieldContainer[Resource]
    message: str
    def __init__(self, status_code: _Optional[int] = ..., resources: _Optional[_Iterable[_Union[Resource, _Mapping]]] = ..., message: _Optional[str] = ...) -> None: ...

class ResourceListRequest(_message.Message):
    __slots__ = ("type", "permission_types", "parent", "subject")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_TYPES_FIELD_NUMBER: _ClassVar[int]
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    type: Resource.Type
    permission_types: _containers.RepeatedScalarFieldContainer[int]
    parent: Resource
    subject: _subject_pb2.Subject
    def __init__(self, type: _Optional[_Union[Resource.Type, str]] = ..., permission_types: _Optional[_Iterable[int]] = ..., parent: _Optional[_Union[Resource, _Mapping]] = ..., subject: _Optional[_Union[_subject_pb2.Subject, _Mapping]] = ...) -> None: ...

class ResourceListResponse(_message.Message):
    __slots__ = ("status_code", "resources")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    resources: _containers.RepeatedCompositeFieldContainer[Resource]
    def __init__(self, status_code: _Optional[int] = ..., resources: _Optional[_Iterable[_Union[Resource, _Mapping]]] = ...) -> None: ...
